import PySimpleGUI as sg
import pandas as pd
from matplotlib import pyplot as plt
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg


def graficar(canvas, figure):
    figure_canvas_agg = FigureCanvasTkAgg(figure, canvas)
    figure_canvas_agg.draw()
    figure_canvas_agg.get_tk_widget().pack(side='top', fill='both', expand=1)
    return figure_canvas_agg


def obtener_datos():
    url = "https://es.wikipedia.org/wiki/Copa_Am%C3%A9rica"
    result = pd.read_html(url)
    goleadores_x_edicion = result[12]
    gol_argentinos = goleadores_x_edicion[goleadores_x_edicion["Selección"].str.contains("Argentina")]
    gol_brasileros = goleadores_x_edicion[goleadores_x_edicion["Selección"].str.contains("Brasil")]
    etiquetas = ["Argentina", "Brasil"]
    data_dibujo = [gol_argentinos["Goles"].astype(int).sum(), gol_brasileros["Goles"].astype(int).sum()]
    return etiquetas, data_dibujo


AppFont = 'Any 16'
sg.theme('LightGrey')

layout = [[sg.Canvas(key='figCanvas')],
          [sg.Button('Salir', font=AppFont)]]
window = sg.Window('Argentina vs. Brasil',
                   layout,
                   finalize=True,
                   resizable=True,
                   element_justification="right")

etiquetas, data_dibujo = obtener_datos()

explode = (0.1, 0)
fig = plt.figure()
plt.pie(data_dibujo, explode=explode, labels=etiquetas, autopct='%1.2f%%',
        shadow=True, startangle=90, labeldistance=1.1)
plt.axis('equal')
plt.legend(etiquetas)

plt.title("Esaaaaa!!!!")

graficar(window['figCanvas'].TKCanvas, fig)

while True:
    event, values = window.read(timeout=200)
    if event == sg.WIN_CLOSED or event == 'Salir':
        break
window.close()
